==> media_service-tomato-20190614.074410-29-sources.jar: com/jz/jar/media/service/TomatoImageTextService.java <==
package com.jz.jar.media.service;

import java.util.Collection;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import com.jz.jar.media.repository.TomatoImageTextRepository;
import com.jz.jooq.media.tables.pojos.TomatoImageText;

@Lazy
@Service
public class TomatoImageTextService {

	@Autowired
	private TomatoImageTextRepository tomatoImageTextRepository;

	public List<TomatoImageText> findOnlineImageText(Collection<String> iids) {
		return tomatoImageTextRepository.findOnlineImageText(iids);
	}

	public TomatoImageText getOnlineImageText(String iid) {
		return tomatoImageTextRepository.getOnlineImageText(iid);
	}

	public List<String> findImageTextIdForPlaylist(String pid) {
		return tomatoImageTextRepository.findImageTextIdForPlaylist(pid);
	}

	public int countImageTextIdForPlaylist(String pid) {
		return tomatoImageTextRepository.countImageTextIdForPlaylist(pid);
	}

	public List<String> findImageTextIdForPlaylist(String pid, int start, int size) {
		return tomatoImageTextRepository.findImageTextIdForPlaylist(pid, start, size);
	}

	public boolean isExistImageTextForPlaylist(String pid, String iid) {
		return tomatoImageTextRepository.isExistImageTextForPlaylist(pid, iid);
	}

	public String getPlaylistForImageText(String iid) {
		return tomatoImageTextRepository.getPlaylistForImageText(iid);
	}
	
	public boolean isExistImageText(String iid) {
		return tomatoImageTextRepository.isExistImageText(iid);
	}
}

==> media_service-tomato-20190617.031227-31-sources.jar: com/jz/jar/media/service/TomatoImageTextService.java <==
package com.jz.jar.media.service;

import java.util.Collection;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import com.jz.jar.media.repository.TomatoImageTextRepository;
import com.jz.jooq.media.tables.pojos.TomatoImageText;

@Lazy
@Service
public class TomatoImageTextService {

	@Autowired
	private TomatoImageTextRepository tomatoImageTextRepository;

	public List<TomatoImageText> findOnlineImageText(Collection<String> iids) {
		return tomatoImageTextRepository.findOnlineImageText(iids);
	}

	public TomatoImageText getOnlineImageText(String iid) {
		return tomatoImageTextRepository.getOnlineImageText(iid);
	}

	public List<String> findImageTextIdForPlaylist(String pid) {
		return tomatoImageTextRepository.findImageTextIdForPlaylist(pid);
	}

	public int countImageTextIdForPlaylist(String pid) {
		return tomatoImageTextRepository.countImageTextIdForPlaylist(pid);
	}

	public List<String> findImageTextIdForPlaylist(String pid, int start, int size) {
		return tomatoImageTextRepository.findImageTextIdForPlaylist(pid, start, size);
	}

	public boolean isExistImageTextForPlaylist(String pid, String iid) {
		return tomatoImageTextRepository.isExistImageTextForPlaylist(pid, iid);
	}

	public String getPlaylistForImageText(String iid) {
		return tomatoImageTextRepository.getPlaylistForImageText(iid);
	}
	
	public boolean isExistImageText(String iid) {
		return tomatoImageTextRepository.isExistImageText(iid);
	}
	
	public boolean isOnlineImageText(String iid) {
		return tomatoImageTextRepository.isOnlineImageText(iid);
	}
}
